@@ -1,5 +1,6 @@
 use crate::sorts::lsb_radix_sort::lsb_radix_sort_adapter;
 use crate::sorts::recombinating_sort::recombinating_sort;
+use crate::sorts::regions_sort::regions_sort;
 use crate::sorts::scanning_radix_sort::scanning_radix_sort;
 use crate::tuning_parameters::TuningParameters;
 use crate::RadixKey;
@@ -20,22 +21,49 @@ impl SortManager {
         }
     }
 
+    #[cfg(feature = "tuning")]
+    pub fn new_with_tuning<T>(tuning: TuningParameters) -> Self
+    where
+        T: RadixKey + Sized + Send + Sync + Copy,
+    {
+        assert_ne!(T::LEVELS, 0, "RadixKey must have at least 1 level");
+
+        Self { tuning }
+    }
+
     pub fn sort<T>(&self, bucket: &mut [T])
     where
         T: RadixKey + Sized + Send + Sync + Copy,
     {
-        if bucket.len() < 2 {
+        let bucket_len = bucket.len();
+
+        if bucket_len <= 1 {
             return;
         }
 
-        let parallel_count = bucket.len() >= self.tuning.par_count_threshold;
+        let parallel_count = bucket_len >= self.tuning.par_count_threshold;
 
-        if bucket.len() >= self.tuning.scanning_sort_threshold {
-            scanning_radix_sort(&self.tuning, bucket, T::LEVELS - 1, parallel_count);
-        } else if bucket.len() >= self.tuning.recombinating_sort_threshold {
-            recombinating_sort(&self.tuning, bucket, T::LEVELS - 1);
-        } else {
-            lsb_radix_sort_adapter(bucket, 0, T::LEVELS - 1);
+        match bucket_len {
+            n if n >= self.tuning.scanning_sort_threshold => {
+                scanning_radix_sort(&self.tuning, bucket, T::LEVELS - 1, parallel_count)
+            }
+            n if n >= self.tuning.recombinating_sort_threshold => {
+                recombinating_sort(&self.tuning, bucket, T::LEVELS - 1)
+            }
+            _ => lsb_radix_sort_adapter(bucket, 0, T::LEVELS - 1),
+        };
+    }
+
+    pub fn sort_inplace<T>(&self, bucket: &mut [T])
+    where
+        T: RadixKey + Sized + Send + Sync + Copy,
+    {
+        let bucket_len = bucket.len();
+
+        if bucket_len <= 1 {
+            return;
         }
+
+        regions_sort(&self.tuning, bucket, T::LEVELS - 1);
     }
 }
