@@ -49,7 +49,7 @@ where
 }
 
 #[allow(dead_code)]
-pub fn ska_sort_adapter<T>(tuning: &TuningParameters, bucket: &mut [T], level: usize)
+pub fn ska_sort_adapter<T>(tuning: &TuningParameters, inplace: bool, bucket: &mut [T], level: usize)
 where
     T: RadixKey + Sized + Send + Copy + Sync,
 {
@@ -70,7 +70,7 @@ where
 
     bucket
         .arbitrary_chunks_mut(counts.to_vec())
-        .for_each(|chunk| director(tuning, chunk, len, level - 1));
+        .for_each(|chunk| director(tuning, inplace, chunk, len, level - 1));
 }
 
 #[cfg(test)]
@@ -85,7 +85,7 @@ mod tests {
     {
         let tuning = TuningParameters::new(T::LEVELS);
         sort_comparison_suite(shift, |inputs| {
-            ska_sort_adapter(&tuning, inputs, T::LEVELS - 1)
+            ska_sort_adapter(&tuning, true, inputs, T::LEVELS - 1)
         });
     }
 
