@@ -1,7 +1,10 @@
 use std::cmp::max;
 
+#[derive(Clone)]
 pub struct TuningParameters {
     pub cpus: usize,
+    pub regions_sort_threshold: usize,
+    pub inplace_sort_lsb_threshold: usize,
     pub recombinating_sort_threshold: usize,
     pub scanning_sort_threshold: usize,
     pub ska_sort_threshold: usize,
@@ -14,6 +17,8 @@ impl TuningParameters {
         let cpus = rayon::current_num_threads();
         Self {
             cpus,
+            regions_sort_threshold: Self::regions_sort_threshold(),
+            inplace_sort_lsb_threshold: Self::inplace_sort_lsb_threshold(),
             recombinating_sort_threshold: Self::recombinating_sort_threshold(),
             scanning_sort_threshold: Self::scanning_sort_threshold(),
             ska_sort_threshold: Self::ska_sort_threshold(levels),
@@ -22,6 +27,14 @@ impl TuningParameters {
         }
     }
 
+    fn regions_sort_threshold() -> usize {
+        150_000
+    }
+
+    fn inplace_sort_lsb_threshold() -> usize {
+        50_000
+    }
+
     fn recombinating_sort_threshold() -> usize {
         150_000
     }
